@@ -87,4 +87,19 @@ LITERATURE_FACTS = [
     {"question": "Mention the year in which the first free library of Britain opened?", "answer": "1852"},
     {"question": "Name the Italian Astronomer who is the author of The Starry Messenger?", "answer": "Galileo"},
     {"question": "Name the Shakespearean character who had spoken the maximum number of lines?", "answer": "Hamlet"}
+]
+
+GENERAL_FACTS = [
+    {"question": "Which planet looks reddish in the night sky?", "answer": "Mars"},
+    {"question": "Which country lies directly to the east of Iraq?", "answer": "Iran"},
+    {"question": "What was the source of the blue gem stone, lapis lazuli, for the people of Harappan culture?", "answer": "Afghanistan"},
+    {"question": "Sachin Tendulkar scored his 100th international century against which’ country ?", "answer": "Bangladesh"},
+    {"question": "Which east African language developed as the lingua franca between Africans and Arab traders?", "answer": "Swahili"},
+    {"question": "In baseball, the two opposing teams consist of how many players?", "answer": "9"},
+    {"question": "Which country is the world’s leading producer of olives and grapes?", "answer": "Italy"},
+    {"question": "In 1610, Galileo Galilei discovered four moons of which planet?", "answer": "Jupiter"},
+    {"question": "Which legal term indicates pledging of properties?", "answer": "Mortgage"},
+    {"question": "In the Vedic society, which was the term used to denote a group of families?", "answer": "Grama"},
+    {"question": "In which country did the Baha’i religion originate?", "answer": "Iran"},
+    {"question": "Which district of London gave its name to the Prime Meridian?", "answer": "Greenwich"}
 ]
\ No newline at end of file
